@@ -67,6 +67,8 @@ public class AvgLinkHierarchicalClustering {
     protected boolean singleLinkage = false;    //by default, use average linkage clustering
     protected ArrayList labelHighlight; //a list of LabelColorPair objects
 
+    
+
 
     /**
      * linkedLeaves: pairs of leaves linked at each node of the result. Each row in this matrix
@@ -374,6 +376,16 @@ public class AvgLinkHierarchicalClustering {
         this.optimalLeafOrdering = optimalLeafOrdering;
     }
 
+    public void setLeafOrderingMethod(String leafOrderingMethod) {
+        if (leafOrderingMethod == Brain.LEAF_ORDERING_BARJOSEPH2003) {
+            this.optimalLeafOrdering = true;
+        }
+        else {
+            this.optimalLeafOrdering = false;
+        }
+
+    }
+
     public boolean isSingleLinkage() {
         return singleLinkage;
     }
