@@ -696,7 +696,7 @@ public class LogoTreeDraw {
 //            }
 
             ProteinProfile comboProfile = null;
-            comboProfile = new ProteinProfile(profileListForNode, "Node" + node.nodeIndex, null);
+            comboProfile = new ProteinProfile(profileListForNode, "Node" + node.nodeIndex, profileAlignment);
             comboProfileList.set(node.nodeIndex - 1, comboProfile); //-1 because other logo code expects comboProfileList to start at 0
             collectComboProfiles(node.left, profileList, comboProfileList);
             collectComboProfiles(node.right, profileList, comboProfileList);
