@@ -5,6 +5,7 @@ import org.biojava.bio.BioException;
 import org.biojava.bio.dist.Distribution;
 import org.biojava.bio.dist.DistributionTools;
 import org.biojava.bio.dist.DistributionFactory;
+import org.biojava.bio.dist.SimpleDistribution;
 import org.biojava.bio.dp.SimpleWeightMatrix;
 import org.biojava.bio.dp.WeightMatrix;
 import org.biojava.bio.seq.ProteinTools;
@@ -244,50 +245,48 @@ public class ProteinProfile {
         //we return the aggregate profile of the 2 "closest" profiles
         else {
 
-            System.out.println("Combining " + profileList.size() + " profiles for " + name);
+            System.out.println("\nCombining " + profileList.size() + " profiles for " + name);
 
             //determine the size of the average profile based on the absolute alignment positions of the profiles
             int numColumns = 0;
+            int minPosition = Integer.MAX_VALUE;
             for (int i = 0; i < profileList.size(); i++) {
                 ProteinProfile proteinProfile = (ProteinProfile) profileList.get(i);
                 int position = profileAlignment.getAbsoluteAlignmentPosition(proteinProfile);
                 numColumns = Math.max(numColumns, position + proteinProfile.getNumColumns());
+                minPosition = Math.min(minPosition, position);
             }
-
-            //debug
-            System.out.println("Profile Size: " + (numColumns - 1));
+            //adjust profile size if leftmost profile didn't start at absolute 0
+            numColumns -= minPosition;
 
             //create the average profile
             try {
+                ProteinProfile tempProfile = (ProteinProfile)profileList.get(0);
+                Distribution[] dists = new Distribution[numColumns];
+                //prepare a set of distributions for the average profile's weight matrix
+                for (int i = 0; i < numColumns; i++) {
+                    dists[i] = DistributionFactory.DEFAULT.createDistribution(tempProfile.getWeightMatrix().getAlphabet());
+                }
+                //assign distribution columns to the weight matrix
+                weightMatrix = new SimpleWeightMatrix(dists);
 
-                //BUG: wmAlphabet has 22 symbols, so resulting weightMatrix has 22 symbols
-                //      but 'alphabet' (global to this class) has only 20 symbols
-                //      so 2 symbols don't get initialized in the loop below and their weights are NaN
-                //      these NaN will later cause empty sequence logos for all internal node profiles
-                Alphabet wmAlphabet = ((ProteinProfile)profileList.get(0)).getWeightMatrix().getAlphabet();
-                weightMatrix = new SimpleWeightMatrix(wmAlphabet, numColumns, DistributionFactory.DEFAULT);
-
-                
-
-                //initialize average profile's weights 0
+                //initialize all weights to 0
                 for (int i = 0; i < weightMatrix.columns(); i++) {
                     Distribution column = weightMatrix.getColumn(i);
-                    Iterator symbolIterator = alphabet.iterator();
-                    while (symbolIterator.hasNext()) {
-                        Symbol symbol = (Symbol) symbolIterator.next();
+                    for (Iterator iter = ((FiniteAlphabet)weightMatrix.getColumn(0).getAlphabet()).iterator(); iter.hasNext();) {
+                        Symbol symbol = (Symbol) iter.next();
                         column.setWeight(symbol, 0.0);
                     }
                 }
 
                 //iterate through profiles to combine all their weight distributions into the average profile
                 for (int i = 0; i < profileList.size(); i++) {
-
                     ProteinProfile proteinProfile = (ProteinProfile) profileList.get(i);
                     int position = profileAlignment.getAbsoluteAlignmentPosition(proteinProfile);
 
                     //add this profile's distributions to the average profile
                     for (int j = 0; j < proteinProfile.getNumColumns(); j++) {
-                        Distribution avgColumn = weightMatrix.getColumn(position + j);
+                        Distribution avgColumn = weightMatrix.getColumn(position + j - minPosition);
                         Distribution profileColumn = proteinProfile.getWeightMatrix().getColumn(j);
 
                         //add the weights for each alphabet symbol
@@ -296,8 +295,9 @@ public class ProteinProfile {
                             Symbol symbol = (Symbol) symbolIterator.next();
                             double weight = 0.0;
                             try {
-
+                                //this is just a hack to avoid NaN values in the
                                 weight = avgColumn.getWeight(symbol) + profileColumn.getWeight(symbol);
+
                                 //if we are at the end of the profile list, take the average
                                 if (i != (profileList.size() - 1)) {
                                     //not at end yet
