@@ -192,7 +192,7 @@ public class ProteinProfileDistance {
      * @param profile2
      * @return
      */
-    static public int calculateOptimalAlignedPosition(ProteinProfile profile1, ProteinProfile profile2) {
+    static public int calculateOptimalAlignedPosition(ProteinProfile profile1, ProteinProfile profile2, String grouping) {
 
         double minDistance = Double.MAX_VALUE;
         double distance;
@@ -234,8 +234,6 @@ public class ProteinProfileDistance {
             minProfileSize = trimProfile1.getNumColumns();
             profilesSwapped = true;
         }
-        //TODO: distance calculation method (no grouping, grouped by charge, etc.) should be a parameter
-        String groupingByPosition = AminoAcidGrouping.getPolarChargedHydrophobeGrouping();
         ProteinProfile p1, p2;
         int profileLengthSum = minProfile.getNumColumns() + maxProfile.getNumColumns();
 
@@ -247,9 +245,7 @@ public class ProteinProfileDistance {
             for (int i = 0; i < (minProfileSize - 1); i++) {
                 p1 = maxProfile.getProfileSubsetCopy(0 + "-" + i);
                 p2 = minProfile.getProfileSubsetCopy((minProfileSize - i - 1) + "-" + (minProfileSize - 1));
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
-//                distance = calculateDistributionDistance(p1, p2);
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                     section = 1;
@@ -270,9 +266,7 @@ public class ProteinProfileDistance {
             for (int i = 0; i < (maxProfileSize - minProfileSize + 1); i++) {
                 p1 = maxProfile.getProfileSubsetCopy(i + "-" + (i + minProfileSize - 1));
                 p2 = minProfile.getProfileSubsetCopy(0 + "-" + (minProfileSize - 1));
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
-//                distance = calculateDistributionDistance(p1, p2);
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                     section = 2;
@@ -292,9 +286,7 @@ public class ProteinProfileDistance {
             for (int i = 0; i < (minProfileSize - 1); i++) {
                 p1 = maxProfile.getProfileSubsetCopy((maxProfileSize - minProfileSize + i + 1) + "-" + (maxProfileSize - 1));
                 p2 = minProfile.getProfileSubsetCopy(0 + "-" + (minProfileSize - i - 2));
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
-//                distance = calculateDistributionDistance(p1, p2);
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                     section = 3;
@@ -354,7 +346,7 @@ public class ProteinProfileDistance {
         return optimalPosition;
     }
 
-    static public double calculateOptimalAlignedDistributionDistance(ProteinProfile profile1, ProteinProfile profile2) {
+    static public double calculateOptimalAlignedDistributionDistance(ProteinProfile profile1, ProteinProfile profile2, String grouping) {
 
         double minDistance = Double.MAX_VALUE;
         double distance;
@@ -388,42 +380,26 @@ public class ProteinProfileDistance {
 
         try {
             for (int i = 0; i < (minProfileSize - 1); i++) {
-//                p1 = maxProfile.getTruncatedProfileCopy(i + 1, ProteinTerminus.C);
-//                p2 = minProfile.getTruncatedProfileCopy(i + 1, ProteinTerminus.N);
-//                p1 = maxProfile.getProfileSubsetCopy((i+1) + "-" + maxProfileSize);
-//                p2 = minProfile.getProfileSubsetCopy((minProfileSize - i - 1) + "-" + (minProfileSize - 1));
                 p1 = maxProfile.getProfileSubsetCopy(0 + "-" + i);
                 p2 = minProfile.getProfileSubsetCopy((minProfileSize - i - 1) + "-" + (minProfileSize - 1));
-
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-//                distance = calculateDistributionDistance(p1, p2);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                 }
             }
             for (int i = 0; i < (maxProfileSize - minProfileSize + 1); i++) {
-//                ProteinProfile p0 = maxProfile.getTruncatedProfileCopy(minProfileSize + i, ProteinTerminus.C);
-//                p1 = p0.getTruncatedProfileCopy(minProfileSize, ProteinTerminus.N);
-//                p2 = minProfile;
                 p1 = maxProfile.getProfileSubsetCopy(i + "-" + (i + minProfileSize - 1));
                 p2 = minProfile.getProfileSubsetCopy(0 + "-" + (minProfileSize - 1));
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-//                distance = calculateDistributionDistance(p1, p2);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                 }
 
             }
             for (int i = 0; i < (minProfileSize - 1); i++) {
-//                p1 = maxProfile.getTruncatedProfileCopy(minProfileSize - i - 1, ProteinTerminus.N);
-//                p2 = minProfile.getTruncatedProfileCopy(minProfileSize - i - 1, ProteinTerminus.C);
                 p1 = maxProfile.getProfileSubsetCopy((maxProfileSize - minProfileSize + i + 1) + "-" + (maxProfileSize - 1));
                 p2 = minProfile.getProfileSubsetCopy(0 + "-" + (minProfileSize - i - 2));
-//                distance = calculateAAGroupedDistributionDistance(p1, p2, groupingByPosition);
-//                distance = calculateDistributionDistance(p1, p2);
-                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns());
+                distance = calculateWeightedDistributionDistance(p1, p2, profileLengthSum - p1.getNumColumns(), grouping);
                 if (distance < minDistance) {
                     minDistance = distance;
                 }
@@ -457,7 +433,7 @@ public class ProteinProfileDistance {
      * @param profile2 Profile 2 (distance to)
      * @return The fractional distance from profile 1 to 2 (0 = identical, 1 = farthest apart)
      */
-    static public double calculateWeightedDistributionDistance(ProteinProfile profile1, ProteinProfile profile2, int maxColumns) {
+    static public double calculateWeightedDistributionDistance(ProteinProfile profile1, ProteinProfile profile2, int maxColumns, String grouping) {
         if (profile1.getNumColumns() != profile2.getNumColumns()) {
             throw new IllegalArgumentException("Profiles to be compared must be the same length.");
         }
@@ -465,26 +441,47 @@ public class ProteinProfileDistance {
         ArrayList alphabet = get20aaAlphabet();  //save the 20 aa alphabet for fast use
 
         double distance = 0.0;
-        double penalty = 0.0;
+        double penalty;
 
-        WeightMatrix wm1 = profile1.getWeightMatrix();
-        WeightMatrix wm2 = profile2.getWeightMatrix();
 
-        try {
-            for (int i = 0; i < wm1.columns(); i++) {
-                Distribution d1 = wm1.getColumn(i);
-                Distribution d2 = wm2.getColumn(i);
-                Iterator l = alphabet.iterator();
+        if (grouping != null) {
+            String[] groupingArray = grouping.split("[, ]");
+            double[][] groupedWeightMatrix1 = convertWeightMatrixToGroupWeightMatrix(groupingArray, profile1.getWeightMatrix(), alphabet);
+            double[][] groupedWeightMatrix2 = convertWeightMatrixToGroupWeightMatrix(groupingArray, profile2.getWeightMatrix(), alphabet);
+            //calculate distance between grouped matrices
+            //iterate through columns
+            for (int j = 0; j < groupedWeightMatrix1.length; j++) {
+                double[] column1 = groupedWeightMatrix1[j];
+                double[] column2 = groupedWeightMatrix2[j];
                 double weightSum = 0.0;
-                while (l.hasNext()) {
-                    Symbol symbol = (Symbol) l.next();
-                    weightSum += Math.pow(d1.getWeight(symbol) - d2.getWeight(symbol), 2);
+                for (int k = 0; k < column1.length; k++) { //length == number of groups in grouping
+                    weightSum += Math.pow(column1[k] - column2[k], 2);
                 }
                 weightSum = Math.sqrt(weightSum) / Math.sqrt(2);
-                distance += weightSum;                                  
+                distance += weightSum;
+            }
+        }
+        else {
+            WeightMatrix wm1 = profile1.getWeightMatrix();
+            WeightMatrix wm2 = profile2.getWeightMatrix();
+
+            try {
+                for (int i = 0; i < wm1.columns(); i++) {
+                    Distribution d1 = wm1.getColumn(i);
+                    Distribution d2 = wm2.getColumn(i);
+                    Iterator l = alphabet.iterator();
+                    double weightSum = 0.0;
+
+                    while (l.hasNext()) {
+                        Symbol symbol = (Symbol) l.next();
+                        weightSum += Math.pow(d1.getWeight(symbol) - d2.getWeight(symbol), 2);
+                    }
+                    weightSum = Math.sqrt(weightSum) / Math.sqrt(2);
+                    distance += weightSum;
+                }
+            } catch (IllegalSymbolException e) {
+                e.printStackTrace();
             }
-        } catch (IllegalSymbolException e) {
-            e.printStackTrace();
         }
 
         //distance = distance / profile1.getNumColumns();
